<?php
// Configuración
$homeDir = '/home/ppuphcom/public_html';
$zipFile = $homeDir . '/public_html.zip';

// Verificar que el directorio home existe
if (!is_dir($homeDir)) {
    die("Error: El directorio $homeDir no existe o no es accesible.\n");
}

// Eliminar ZIP anterior si existe
if (file_exists($zipFile)) {
    unlink($zipFile);
}

$zip = new ZipArchive();
if ($zip->open($zipFile, ZipArchive::CREATE | ZipArchive::OVERWRITE) !== TRUE) {
    die("Error: No se pudo crear el archivo ZIP.\n");
}

// Directorios y archivos a excluir
$exclusions = ['.cagefs', '.cpanel', 'tmp'];

// Función recursiva para agregar archivos al ZIP, excluyendo algunos
function addFilesToZip($zip, $folderPath, $localPath = '', $exclusions = []) {
    $files = scandir($folderPath);

    foreach ($files as $file) {
        if ($file === '.' || $file === '..') continue;

        $fullPath = $folderPath . '/' . $file;
        $relativePath = $localPath . $file;

        // Verificar si el archivo o directorio está en la lista de exclusiones
        foreach ($exclusions as $exclude) {
            if (strpos($fullPath, $exclude) !== false) {
                echo "Excluyendo: $fullPath\n";
                continue 2;  // Saltar este archivo/directorio
            }
        }

        if (is_dir($fullPath)) {
            $zip->addEmptyDir($relativePath);
            addFilesToZip($zip, $fullPath, $relativePath . '/', $exclusions);
        } else {
            if (!$zip->addFile($fullPath, $relativePath)) {
                echo "Advertencia: No se pudo agregar $fullPath al ZIP.\n";
            }
        }
    }
}

// Ejecutar la función
addFilesToZip($zip, $homeDir, '', $exclusions);

// Cerrar el archivo ZIP
if (!$zip->close()) {
    die("Error: No se pudo cerrar el archivo ZIP.\n");
}

echo "El archivo ZIP se ha creado correctamente en: $zipFile\n";
?>
